@@ -9,8 +9,10 @@ Ext.define('Ux.locale.override.extjs.Button', {
         var me          = this,
             locales     = me.locales,
             text        = locales.text,
+            tooltip        = locales.tooltip,
             manager     = me.locale,
             defaultText = '';
+            defaultTooltip = '';
         
         if (text) {            
             if (Ext.isObject(text)) {
@@ -25,6 +27,19 @@ Ext.define('Ux.locale.override.extjs.Button', {
             }
         }
 
+        if (tooltip) {                     
+            if (Ext.isObject(tooltip)) {
+                defaultText = tooltip.defaultText;
+                tooltip     = tooltip.key;
+            }
+
+            tooltip = manager.get(tooltip, defaultText);
+
+            if (Ext.isString(tooltip)) {                
+                me.setTooltip(tooltip);
+            }
+        }
+
         me.callOverridden(arguments);
     }
 });
\ No newline at end of file
